pub struct BashOptions {
pub timeout: Duration,
pub max_timeout: Duration,
pub max_output_bytes: usize,
}Fields
timeout: DurationUsed when the call does not ask for a timeout.
max_timeout: DurationCeiling for what a call may ask for, so a hung command cannot run unbounded.
max_output_bytes: usizeTrait Implementations
Sourceimpl Clone for BashOptions
impl Clone for BashOptions
Sourcefn clone(&self) -> BashOptions
fn clone(&self) -> BashOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for BashOptions
impl RefUnwindSafe for BashOptions
impl Send for BashOptions
impl Sync for BashOptions
impl Unpin for BashOptions
impl UnsafeUnpin for BashOptions
impl UnwindSafe for BashOptions